#include <SDL.h>
#include <SDL_image.h>
#include <iostream>

#include <godlibdefines.h>
#include <gp2x.h>
#include <sdltools.h>
#include <sdlttf.h>
#include <image.h>
#include <music.h>
#include <sample.h>
#include <sprite.h>

using namespace std;

SDL_Surface *screen = NULL;
SDL_Joystick *joy = NULL;

void Terminate(void) {
	closeAudioSystem();
	SDL_Quit();
#ifdef GP2X
	chdir("/usr/gp2x");
	execl("/usr/gp2x/gp2xmenu", "/usr/gp2x/gp2xmenu", NULL);
#endif
}

int main (int argc, char **argv) {
	int done=0;

	if (SDL_Init (SDL_INIT_VIDEO | SDL_INIT_AUDIO | SDL_INIT_JOYSTICK) < 0) {
		fprintf (stderr, "Couldn't initialize SDL: %s\n", SDL_GetError ());
		exit (1);
	}
	atexit (Terminate);

	SDL_ShowCursor(SDL_DISABLE);

	screen = SDL_SetVideoMode (SCREEN_WIDTH, SCREEN_HEIGHT, 16, SDL_SWSURFACE);
	if (screen == NULL) {
		fprintf (stderr, "Couldn't set 320x240x16 video mode: %s\n", SDL_GetError ());
		exit (2);
	}

	if (SDL_NumJoysticks() > 0) {
		joy = SDL_JoystickOpen(0);
		if(!joy) {
			fprintf (stderr, "Couldn't open joystick 0: %s\n", SDL_GetError ());
		}
	}

	if (TTF_Init() == -1) {
		exit(3);
	}

#ifdef LINUX
#endif

#ifdef GP2X
#endif
	initAudioSystem();

	SDLTTF *ttf=new SDLTTF(FONT,12);
	ttf->setForegroundColor(255,255,0);

	SDL_Event event;

	Image test("data/plasma.png");
	cout << test.getWidth()*3 << "," << test.getHeight()*3 << endl;
	SDL_Surface *scaled=sdlCreateSurface(test.getWidth()*3,test.getHeight()*3);

	float rot=0;
	float fact=.5;

	Music mus=Music("data/test.ogg");
	mus.setVolume(64);
	mus.play();

	Sample samp=Sample("data/test.wav");
	cout << samp.loaded << endl;
	samp.play();

	Sprite spr=Sprite("data/fighter.png");

	while (!done) {
		while (SDL_PollEvent (&event)) {
			switch (event.type) {
				case SDL_KEYDOWN:
				case SDL_JOYBUTTONDOWN:
					if (
							( (event.key.keysym.sym == SDLK_c) && (event.key.keysym.mod & (KMOD_LCTRL | KMOD_RCTRL)) ) ||
							( event.jbutton.button == VK_SELECT )
					   ) {
						done = 1;
					}
					if (
							(event.key.keysym.sym==SDLK_RETURN) ||
							(event.jbutton.button == VK_START)
					   ) {
					}
					break;
				case SDL_KEYUP:
					break;
				case SDL_JOYBUTTONUP:
					break;
				case SDL_QUIT:
					done = 1;
					break;
				default:
					break;
			}
		}

		sdlLock(screen);
		sdlRotoZoom(test.getSDLSurface(),scaled,fact,rot);
		SDL_BlitSurface(scaled, NULL, screen, NULL);
		sdlUnlock(screen);
		SDL_Flip(screen);
		SDL_Delay(25);
		rot+=.1;
		if (rot>2*3.14) rot=0;
		fact+=.01;
		if (fact>2) fact=.5;
	}

	cout << "done" << endl;

	return 0;
}
